@@ -1,13 +1,13 @@
 from cms.app_base import CMSApp
 from cms.apphook_pool import apphook_pool
-from .menu import TermMenu
+from .menu import TermsMenu
 from django.utils.translation import ugettext_lazy as _
 
 
-class TermApp(CMSApp):
-    name = _('Term')
+class TermsApp(CMSApp):
+    name = _('Terms')
     urls = ['terms.urls']
-    menus = [TermMenu]
+    menus = [TermsMenu]
 
 
-apphook_pool.register(TermApp)
+apphook_pool.register(TermsApp)
