@@ -5,3 +5,6 @@ from .models import Term
 class TermDetail(DetailView):
     model = Term
     context_object_name = 'term'
+
+    def get_queryset(self):
+        return self.model.objects.exclude(definition='')
